<?php
/**
 * @file
 * Theme implementation to display the Mobile Switch Block content.
 *
 * Available variables:
 * - $content: The complete HTML block content; message and switch link.
 *
 * - $mobile_switch_block_content: Parameter from the Mobile Switch block
 *   configuration to display the block content Possible values:
 *   - link: Display only the switch link.
 *   - message_link: Display a message and the switch link
 * - $version: A string, used in the switch link text and the switch link URL.
 *   Possible values:
 *   - mobile
 *   - standard
 * - $version_text: A string, used in the switch message. Possible values:
 *   - mobile
 *   - standard
 * - $class: A class string to use for the identification of the switch link.
 *   Possible values:
 *   - mobile-switch-to-mobile
 *   - mobile-switch-to-standard
 *
 * - $switch_link: Content of the switch link.
 * - $switch_message: Content of the additional message, prepended to the
 *   switch link.
 *
 * Helper variables:
 * - $user: The user object.
 * - $mobile_switch_ismobiledevice: Boolean value.
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 * - $zebra: Outputs 'odd' and 'even' dependent on each block region.
 * - $id: Counter dependent on each block region independent of any block region.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 * - $switch_content_html_id: A valid HTML ID and guaranteed unique.
 *
 * @see template_preprocess_mobile_switch_block()
 *
 * @ingroup themeable
 */
?>
<div id="<?php print $switch_content_html_id ?>" class="<?php print $class ?>">
<?php if ($switch_message): ?>
  <span class="mobile-switch-inform">
    <?php print $switch_message ?>
  </span>
<?php endif;?>
  <ul class="menu clearfix">
    <li class="leaf even first last">
      <?php print $switch_link ?>
    </li>
  </ul>
</div>
